==> visier_api_analytic_model-0.99201.1876b1-py3-none-any.whl: visier_api_analytic_model/models/servicing_v2_objectconfiguration_concept_delete_with_context_dto.py <==
# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1876
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_concept_delete_dto import ServicingV2ObjectconfigurationConceptDeleteDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_execution_context_dto import ServicingV2ObjectconfigurationExecutionContextDTO
from typing import Optional, Set
from typing_extensions import Self

class ServicingV2ObjectconfigurationConceptDeleteWithContextDTO(BaseModel):
    """
    Information about the concept to delete and the context of the API request, such as the tenant code and project ID.
    """ # noqa: E501
    execution_context: Optional[ServicingV2ObjectconfigurationExecutionContextDTO] = Field(default=None, description="The context of the API request, such as the tenant code and project ID.", alias="executionContext")
    concept: Optional[ServicingV2ObjectconfigurationConceptDeleteDTO] = Field(default=None, description="Information identifying the concept to delete.")
    __properties: ClassVar[List[str]] = ["executionContext", "concept"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServicingV2ObjectconfigurationConceptDeleteWithContextDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of execution_context
        if self.execution_context:
            _dict['executionContext'] = self.execution_context.to_dict()
        # override the default output from pydantic by calling `to_dict()` of concept
        if self.concept:
            _dict['concept'] = self.concept.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServicingV2ObjectconfigurationConceptDeleteWithContextDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "executionContext": ServicingV2ObjectconfigurationExecutionContextDTO.from_dict(obj["executionContext"]) if obj.get("executionContext") is not None else None,
            "concept": ServicingV2ObjectconfigurationConceptDeleteDTO.from_dict(obj["concept"]) if obj.get("concept") is not None else None
        })
        return _obj

==> visier_api_analytic_model-22222222.99201.1892-py3-none-any.whl: visier_api_analytic_model/models/servicing_v2_objectconfiguration_concept_delete_with_context_dto.py <==
# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1892
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_execution_context_dto import ServicingV2ObjectconfigurationExecutionContextDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_object_id_dto import ServicingV2ObjectconfigurationObjectIdDTO
from typing import Optional, Set
from typing_extensions import Self

class ServicingV2ObjectconfigurationConceptDeleteWithContextDTO(BaseModel):
    """
    Information about the concept to delete and the context of the API request, such as the tenant code and project ID.
    """ # noqa: E501
    execution_context: Optional[ServicingV2ObjectconfigurationExecutionContextDTO] = Field(default=None, description="The context of the API request, such as the tenant code and project ID.", alias="executionContext")
    concept: Optional[ServicingV2ObjectconfigurationObjectIdDTO] = Field(default=None, description="Information identifying the concept to delete.")
    __properties: ClassVar[List[str]] = ["executionContext", "concept"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServicingV2ObjectconfigurationConceptDeleteWithContextDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of execution_context
        if self.execution_context:
            _dict['executionContext'] = self.execution_context.to_dict()
        # override the default output from pydantic by calling `to_dict()` of concept
        if self.concept:
            _dict['concept'] = self.concept.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServicingV2ObjectconfigurationConceptDeleteWithContextDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "executionContext": ServicingV2ObjectconfigurationExecutionContextDTO.from_dict(obj["executionContext"]) if obj.get("executionContext") is not None else None,
            "concept": ServicingV2ObjectconfigurationObjectIdDTO.from_dict(obj["concept"]) if obj.get("concept") is not None else None
        })
        return _obj
